==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/TemplateSectionHeaderCellInfoDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { SectionHeaderCellInfoDescriptionMetadata } from "./SectionHeaderCellInfoDescriptionMetadata";
import { TemplateSectionHeaderCellInfoDescription } from "./TemplateSectionHeaderCellInfoDescription";
/**
 * @hidden
 */
export let TemplateSectionHeaderCellInfoDescriptionMetadata = /*@__PURE__*/ (() => {
    class TemplateSectionHeaderCellInfoDescriptionMetadata extends Base {
        static b(a) {
            if (TemplateSectionHeaderCellInfoDescriptionMetadata.a == null) {
                TemplateSectionHeaderCellInfoDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                TemplateSectionHeaderCellInfoDescriptionMetadata.c(TemplateSectionHeaderCellInfoDescriptionMetadata.a);
            }
            if (a.k(TemplateSectionHeaderCellInfoDescriptionMetadata.a)) {
                return;
            }
            a.ab(TemplateSectionHeaderCellInfoDescriptionMetadata.a);
        }
        static c(a) {
            SectionHeaderCellInfoDescriptionMetadata.c(a);
        }
        static d(a) {
            TemplateSectionHeaderCellInfoDescriptionMetadata.b(a);
            a.ad("TemplateSectionHeaderCellInfo", () => new TemplateSectionHeaderCellInfoDescription());
            a.ac("TemplateSectionHeaderCellInfo", TemplateSectionHeaderCellInfoDescriptionMetadata.a);
        }
    }
    TemplateSectionHeaderCellInfoDescriptionMetadata.$t = markType(TemplateSectionHeaderCellInfoDescriptionMetadata, 'TemplateSectionHeaderCellInfoDescriptionMetadata');
    TemplateSectionHeaderCellInfoDescriptionMetadata.a = null;
    return TemplateSectionHeaderCellInfoDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/TemplateSectionHeaderCellInfoDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { SectionHeaderCellInfoDescriptionMetadata } from "./SectionHeaderCellInfoDescriptionMetadata";
import { TemplateSectionHeaderCellInfoDescription } from "./TemplateSectionHeaderCellInfoDescription";
/**
 * @hidden
 */
export let TemplateSectionHeaderCellInfoDescriptionMetadata = /*@__PURE__*/ (() => {
    class TemplateSectionHeaderCellInfoDescriptionMetadata extends Base {
        static b(a) {
            if (TemplateSectionHeaderCellInfoDescriptionMetadata.a == null) {
                TemplateSectionHeaderCellInfoDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                TemplateSectionHeaderCellInfoDescriptionMetadata.c(TemplateSectionHeaderCellInfoDescriptionMetadata.a);
            }
            if (a.k(TemplateSectionHeaderCellInfoDescriptionMetadata.a)) {
                return;
            }
            a.ac(TemplateSectionHeaderCellInfoDescriptionMetadata.a);
        }
        static c(a) {
            SectionHeaderCellInfoDescriptionMetadata.c(a);
        }
        static d(a) {
            TemplateSectionHeaderCellInfoDescriptionMetadata.b(a);
            a.ae("TemplateSectionHeaderCellInfo", () => new TemplateSectionHeaderCellInfoDescription());
            a.ad("TemplateSectionHeaderCellInfo", TemplateSectionHeaderCellInfoDescriptionMetadata.a);
        }
    }
    TemplateSectionHeaderCellInfoDescriptionMetadata.$t = markType(TemplateSectionHeaderCellInfoDescriptionMetadata, 'TemplateSectionHeaderCellInfoDescriptionMetadata');
    TemplateSectionHeaderCellInfoDescriptionMetadata.a = null;
    return TemplateSectionHeaderCellInfoDescriptionMetadata;
})();
